@@ -8,16 +8,20 @@ Siebel::Srvrmgr::Daemon::ActionStash - singleton to stash data returned by Siebe
 
 =head1 SYNOPSIS
 
-    package MyAction;
-    use Moose;
-    use namespace::autoclean;
+package MyAction;
+use Moose;
+use namespace::autoclean;
 
-    extends 'Siebel::Srvrmgr::Daemon::Action';
+extends 'Siebel::Srvrmgr::Daemon::Action';
 
-    my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
-	$stash->set_stash([{foobar => foobar}, [qw(one two three)]]);
+	my $stash = Siebel::Srvrmgr::Daemon::ActionStash->initialize(
+		{
+			key1 => 'foobar', 
+			key2 => 'foobar'
+		}
+	);
 
-    package main;
+package main;
 
 	my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
 
@@ -39,7 +43,10 @@ Considering this situation, the interface of this class should be considered exp
 
 =cut
 
+use warnings;
+use strict;
 use MooseX::Singleton;
+use MooseX::FollowPBP;
 
 =pod
 
@@ -47,21 +54,14 @@ use MooseX::Singleton;
 
 =head2 stash
 
-This attribute is a array reference of references. This means that it will accept B<any> reference to some data structure that you think it will be 
-useful (including objects).
+This attribute is a reference to some data. This means that it will accept B<any> reference to some that structure that you think it will be useful.
 
 If undefined, this attribute will returned an empty array reference.
 
 =cut
 
-has stash => (
-    is       => 'rw',
-    isa      => 'ArrayRef[Ref]',
-    required => 0,
-    reader   => 'get_stash',
-    writer   => 'set_stash',
-    default  => sub { return [] }
-);
+has stash =>
+  ( is => 'rw', isa => 'Ref', required => 0, default => sub { return [] } );
 
 =pod
 
@@ -69,46 +69,11 @@ has stash => (
 
 =head2 get_stash
 
-Returns the C<stash> attribute array reference.
+Returns the C<stash> attribute reference.
 
 =head2 set_stash
 
-Sets the C<stash> attribute. Expects an array reference as parameter.
-
-Beware that such call will complete remove all other data stored in the stash. To add single items, see C<push_stash> method.
-
-=head2 push_stash
-
-Pushes a new reference into the C<stash> attribute.
-
-=cut
-
-sub push_stash {
-
-    my $self = shift;
-    my $ref  = shift;
-
-    push( @{ $self->get_stash() }, $ref );
-
-    return 1;
-
-}
-
-=head2 shift_stash
-
-Shifts the C<stash> attribute, removing the first item in the attribute and returning it.
-
-If there is not other member to be shift, it will return undef.
-
-=cut
-
-sub shift_stash {
-
-    my $self = shift;
-
-    return shift( @{ $self->get_stash() } );
-
-}
+Sets the C<stash> attribute. Expects a reference as parameter.
 
 =head1 SEE ALSO
 
@@ -126,11 +91,11 @@ L<MooseX::Singleton>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
 
 This file is part of Siebel Monitoring Tools.
 
@@ -145,7 +110,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
 
