@@ -432,7 +432,8 @@ sub parse {
     my $fsa = FSA::Rules->new(
         first_line => {
             do => sub {
-                print "Searching for useful data\n";
+                print "Searching for useful data\n"
+                  if ( $ENV{SIEBEL_SRVRMGR_DEBUG} );
             },
             rules => [
                 command_submission => sub {
@@ -816,6 +817,29 @@ L<Siebel::Srvrmgr::ListParser::Buffer>
 
 =back
 
+=head1 AUTHOR
+
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+
+This file is part of Siebel Monitoring Tools.
+
+Siebel Monitoring Tools is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Siebel Monitoring Tools is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+
 =cut
 
 no Moose;
