@@ -2,7 +2,6 @@ package Test::ActionStash;
 
 use Test::Most;
 use Siebel::Srvrmgr::ListParser;
-use Test::Moose 'has_attribute_ok';
 use base 'Test::Class';
 
 sub class { 'Siebel::Srvrmgr::Daemon::ActionStash' }
@@ -12,7 +11,7 @@ sub startup : Tests(startup => 1) {
     use_ok $test->class;
 }
 
-sub constructor : Tests(8) {
+sub constructor : Tests(7) {
 
     my $test  = shift;
     my $class = $test->class;
@@ -24,8 +23,6 @@ sub constructor : Tests(8) {
 
     ok( $stash = $class->new(), 'the constructor should succeed' );
 
-	has_attribute_ok($stash, 'stash');
-
     dies_ok(
         sub {
             $stash_param = $class->new( { key1 => 'value', key2 => 'value' } );
